"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const getCheckDirectoryTasks_1 = require("../helpers/getCheckDirectoryTasks");
const getExifData_1 = require("../helpers/getExifData");
const getStatMDate_1 = require("../helpers/getStatMDate");
const isImageFile_1 = require("../helpers/isImageFile");
const isVideoFile_1 = require("../helpers/isVideoFile");
const moveMediaFile_1 = require("../helpers/moveMediaFile");
const moveUnkownFile_1 = require("../helpers/moveUnkownFile");
const getDirectoryFiles_1 = require("../helpers/getDirectoryFiles");
class Move extends command_1.Command {
    async run() {
        var _a;
        const { flags } = this.parse(Move);
        const source = flags.source;
        const destination = flags.destination;
        const unknown = flags.unknown;
        const existing = flags.existing;
        const format = flags.format;
        const name = flags.name;
        const tags = flags.tags;
        const checkDirectoryTasks = getCheckDirectoryTasks_1.getCheckDirectoryTasks({ source, destination, unknown, existing });
        await checkDirectoryTasks.run().catch(() => this.exit());
        cli_ux_1.default.action.start('get files');
        const files = await getDirectoryFiles_1.getDirectoryFiles(source);
        cli_ux_1.default.action.stop();
        for (let index = 0; index < files.length; index++) {
            const filepath = files[index];
            if (!(filepath.indexOf('SynoEAStream') >= 0 || filepath.indexOf('@eaDir') >= 0)) {
                this.log(`process file '${filepath}'`);
                const isImage = isImageFile_1.isImageFile(filepath);
                const isVideo = isVideoFile_1.isVideoFile(filepath);
                if (isImage) {
                    const exifData = await getExifData_1.getExifData(filepath);
                    const exifDate = ((_a = exifData === null || exifData === void 0 ? void 0 : exifData.exif) === null || _a === void 0 ? void 0 : _a.DateTimeOriginal) ? new Date(exifData.exif.DateTimeOriginal) : undefined;
                    if (!exifDate || exifDate.getFullYear() === 1970 || isNaN(exifDate.getFullYear())) {
                        const statMDate = await getStatMDate_1.getStatMDate(filepath);
                        if (statMDate) {
                            await moveMediaFile_1.moveMediaFile({ filepath, date: statMDate, source, destination, existing, format, name, tags });
                        }
                    }
                    else {
                        await moveMediaFile_1.moveMediaFile({ filepath, date: exifDate, source, destination, existing, format, name, tags });
                    }
                }
                else if (isVideo) {
                    const statMDate = await getStatMDate_1.getStatMDate(filepath);
                    if (statMDate) {
                        await moveMediaFile_1.moveMediaFile({ filepath, date: statMDate, source, destination, existing, format, name, tags });
                    }
                }
                else {
                    const statMDate = await getStatMDate_1.getStatMDate(filepath);
                    if (statMDate) {
                        moveUnkownFile_1.moveUnkownFile({ filepath, date: statMDate, source, unknown, existing, format, name });
                    }
                }
            }
        }
    }
}
exports.default = Move;
Move.description = 'move files (images, videos) on synology nas';
Move.examples = [
    `$ synology-image-sort move -s ./source -d ./destination -u ./unknown -e ./existing`,
    `$ synology-image-sort move -s ./source -d ./destination -u ./unknown -e ./existing -t`,
    `$ synology-image-sort move -s ./source -d ./destination -u ./unknown -e ./existing -f YYYY/MM.YYYY/DD.MM.YYYY`,
    `$ synology-image-sort move -s ./source -d ./destination -u ./unknown -e ./existing -n DD.MM.YYYY-HH.mm.ss.SSS`,
];
Move.flags = {
    help: command_1.flags.help({ char: 'h' }),
    source: command_1.flags.string({ char: 's', description: 'source directory', required: true }),
    destination: command_1.flags.string({ char: 'd', description: 'destination directory', required: true }),
    unknown: command_1.flags.string({ char: 'u', description: 'unknown directory', required: true }),
    existing: command_1.flags.string({ char: 'e', description: 'existing directory', required: true }),
    format: command_1.flags.string({ char: 'f', description: 'date format', default: 'YYYY/MM.YYYY/DD.MM.YYYY' }),
    name: command_1.flags.string({ char: 'n', description: 'file name', default: 'DD.MM.YYYY-HH.mm.ss.SSS' }),
    tags: command_1.flags.boolean({ char: 't', description: 'set folder tags' }),
};
