"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moveMediaFile = void 0;
const formatDate = require("date-fns/format");
const deLocale = require("date-fns/locale/de");
const path = require("path");
const fs = require("fs-extra");
const child_process_1 = require("child_process");
// @ts-ignore
const ExifTool = require("exiftool-kit");
const getFileChecksum_1 = require("./getFileChecksum");
const isImageFile_1 = require("./isImageFile");
const exiftool = new ExifTool();
const getDateDirectories = ({ destination, formattedFolderDate }) => {
    const tmpArray = formattedFolderDate.split('/');
    return tmpArray.map((_, index) => {
        const prev = tmpArray.slice(0, index + 1);
        return `${destination}/${prev.join('/')}`;
    });
};
const createDirectoriesIfNotExist = (directories) => {
    directories.forEach((directory) => {
        const exists = fs.existsSync(directory);
        if (!exists) {
            fs.mkdirSync(directory);
            child_process_1.exec(`synoindex -A ${directory}`);
        }
    });
};
const getFolderTags = ({ filepath, source }) => {
    return filepath
        .replace(source.replace('./', '') + '/', '')
        .replace('/' + path.basename(filepath), '')
        .trim()
        .split('/');
};
const getSourceFileDirectories = ({ filepath, source }) => {
    const directory = filepath
        .replace(source.replace('./', '') + '/', '')
        .replace('/' + path.basename(filepath), '')
        .trim();
    if (!directory)
        return [];
    const tmpArray = directory.split('/');
    return tmpArray
        .map((_, index) => {
        const prev = tmpArray.slice(0, index + 1);
        return `${source}/${prev.join('/')}`;
    })
        .reverse();
};
const setExifFolderTags = ({ filepath, folderTags }) => {
    try {
        exiftool.setTags({
            source: filepath,
            tags: folderTags.map((value) => ({ tag: 'iptc:keywords', value })),
        });
    }
    catch (error) {
        console.log('setExifFolderTags failed', error);
    }
};
exports.moveMediaFile = async ({ filepath, date, source, destination, existing, format, name, tags, }) => {
    try {
        const isImage = isImageFile_1.isImageFile(filepath);
        const formattedFolderDate = formatDate(date, format, { locale: deLocale });
        const formattedFileDate = formatDate(date, name, { locale: deLocale });
        const dateDirectories = getDateDirectories({ destination, formattedFolderDate });
        const directory = `${destination}/${formattedFolderDate}`;
        const fileExtension = path.extname(filepath).replace('.jpeg', '.jpg').toLocaleLowerCase();
        const currentChecksum = getFileChecksum_1.getFileChecksum(filepath);
        const fileName = `${formattedFileDate}-${currentChecksum}${fileExtension}`;
        const sourceFileDirectories = getSourceFileDirectories({ filepath, source });
        createDirectoriesIfNotExist(dateDirectories);
        const exists = fs.existsSync(`${directory}/${fileName}`);
        if (!exists) {
            fs.copyFileSync(filepath, `${directory}/${fileName}`);
            fs.unlinkSync(filepath);
            sourceFileDirectories.forEach((sourceFileDirectory) => {
                const files = fs.readdirSync(sourceFileDirectory);
                if (files.length === 0) {
                    fs.rmdirSync(sourceFileDirectory);
                }
            });
            if (tags && isImage) {
                const folderTags = getFolderTags({ filepath, source });
                if (!!folderTags.length) {
                    setExifFolderTags({ filepath: `${directory}/${fileName}`, folderTags });
                }
            }
            child_process_1.exec(`synoindex -a ${directory}/${fileName}`);
        }
        else {
            const files = fs.readdirSync(existing);
            const index = files.length + 1;
            fs.copyFileSync(filepath, `${existing}/#${index}-${fileName}`);
            fs.unlinkSync(filepath);
            sourceFileDirectories.forEach((sourceFileDirectory) => {
                const files = fs.readdirSync(sourceFileDirectory);
                if (files.length === 0) {
                    fs.rmdirSync(sourceFileDirectory);
                }
            });
        }
        return true;
    }
    catch (error) {
        console.log('moveMediaFile failed', error);
        return false;
    }
};
