"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moveUnkownFile = void 0;
const formatDate = require("date-fns/format");
const deLocale = require("date-fns/locale/de");
const path = require("path");
const fs = require("fs-extra");
const getFileChecksum_1 = require("./getFileChecksum");
const getDateDirectories = ({ unknown, formattedFolderDate }) => {
    const tmpArray = formattedFolderDate.split('/');
    return tmpArray.map((_, index) => {
        const prev = tmpArray.slice(0, index + 1);
        return `${unknown}/${prev.join('/')}`;
    });
};
const createDirectoriesIfNotExist = (directories) => {
    directories.forEach((directory) => {
        const exists = fs.existsSync(directory);
        if (!exists) {
            fs.mkdirSync(directory);
        }
    });
};
const getSourceFileDirectories = ({ filepath, source }) => {
    const directory = filepath
        .replace(source.replace('./', '') + '/', '')
        .replace('/' + path.basename(filepath), '')
        .trim();
    if (!directory)
        return [];
    const tmpArray = directory.split('/');
    return tmpArray
        .map((_, index) => {
        const prev = tmpArray.slice(0, index + 1);
        return `${source}/${prev.join('/')}`;
    })
        .reverse();
};
exports.moveUnkownFile = ({ filepath, date, source, unknown, existing, format, name, }) => {
    try {
        const formattedFolderDate = formatDate(date, format, { locale: deLocale });
        const formattedFileDate = formatDate(date, name, { locale: deLocale });
        const dateDirectories = getDateDirectories({ unknown, formattedFolderDate });
        const directory = `${unknown}/${formattedFolderDate}`;
        const fileExtension = path.extname(filepath).replace('.jpeg', '.jpg').toLocaleLowerCase();
        const currentChecksum = getFileChecksum_1.getFileChecksum(filepath);
        const fileName = `${formattedFileDate}-${currentChecksum}${fileExtension}`;
        const sourceFileDirectories = getSourceFileDirectories({ filepath, source });
        createDirectoriesIfNotExist(dateDirectories);
        const exists = fs.existsSync(`${directory}/${fileName}`);
        if (!exists) {
            fs.copyFileSync(filepath, `${directory}/${fileName}`);
            fs.unlinkSync(filepath);
            sourceFileDirectories.forEach((sourceFileDirectory) => {
                const files = fs.readdirSync(sourceFileDirectory);
                if (files.length === 0) {
                    fs.rmdirSync(sourceFileDirectory);
                }
            });
        }
        else {
            const files = fs.readdirSync(existing);
            const index = files.length + 1;
            fs.copyFileSync(filepath, `${existing}/#${index}-${fileName}`);
            fs.unlinkSync(filepath);
            sourceFileDirectories.forEach((sourceFileDirectory) => {
                const files = fs.readdirSync(sourceFileDirectory);
                if (files.length === 0) {
                    fs.rmdirSync(sourceFileDirectory);
                }
            });
        }
        return true;
    }
    catch (error) {
        console.log('moveUnkownFile failed', error);
        return false;
    }
};
